@@ -15,13 +15,12 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-
 from http.server import HTTPServer, BaseHTTPRequestHandler
 from jinja2 import __version__ as jinja2_version
 import jinjafx, os, io, sys, socket, signal, threading, yaml, json, base64, time, datetime
 import re, argparse, zipfile, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip, requests
 
-__version__ = '22.1.4'
+__version__ = '22.1.6'
 
 try:
   from ansible.constants import DEFAULT_VAULT_ID_MATCH
@@ -32,7 +31,6 @@ except:
 
 lock = threading.RLock()
 base = os.path.abspath(os.path.dirname(__file__))
-os.chdir(base + '/extensions')
 
 aws_s3_url = None
 aws_access_key = None
@@ -334,7 +332,7 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                 gvars['jinja2_extensions'] = ['jinjafx_extension.JinjaFxExtension']
 
               st = round(time.time() * 1000)
-              outputs = jinjafx.JinjaFx().jinjafx(template, data, gvars, 'Output')
+              outputs = jinjafx.JinjaFx().jinjafx(template, data, gvars, 'Output', [base + '/extensions'])
               ocount = 0
   
               jsr = {
